==> dotnet8_8.0.121-8.0.21.orig.tar.xz: src/runtime/src/mono/wasm/Wasm.Build.Tests/Common/BuildAndRunAttribute.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using Xunit.Sdk;

#nullable enable

namespace Wasm.Build.Tests
{
    /// <summary>
    /// Example usage:
    ///     [BuildAndRun(aot: true, parameters: new object[] { arg1, arg2 })]
    ///     public void Test(BuildArgs, arg1, arg2, RunHost, id)
    /// </summary>
    [DataDiscoverer("Xunit.Sdk.DataDiscoverer", "xunit.core")]
    [AttributeUsage(AttributeTargets.Method, AllowMultiple = true, Inherited = true)]
    public class BuildAndRunAttribute : DataAttribute
    {
        private readonly IEnumerable<object?[]> _data;

        public BuildAndRunAttribute(BuildArgs buildArgs, RunHost host = RunHost.All, params object?[] parameters)
        {
            _data = new IEnumerable<object?>[]
                    {
                        new object?[] { buildArgs }.AsEnumerable(),
                    }
                    .AsEnumerable()
                    .Multiply(parameters)
                    .WithRunHosts(host)
                    .UnwrapItemsAsArrays().ToList();
        }

        public BuildAndRunAttribute(bool aot=false, RunHost host = RunHost.All, string? config=null, params object?[] parameters)
        {
            _data = BuildTestBase.ConfigWithAOTData(aot, config)
                    .Multiply(parameters)
                    .WithRunHosts(host)
                    .UnwrapItemsAsArrays().ToList();
        }

        public override IEnumerable<object?[]> GetData(MethodInfo testMethod) => _data;
    }
}

==> dotnet10_10.0.100-10.0.0~rc2.orig.tar.xz: src/runtime/src/mono/wasm/Wasm.Build.Tests/Common/BuildAndRunAttribute.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using Xunit.Sdk;

#nullable enable

namespace Wasm.Build.Tests
{
    /// <summary>
    /// Example usage:
    ///     [BuildAndRun(aot: true, parameters: new object[] { arg1, arg2 })]
    ///     public void Test(ProjectInfo, arg1, arg2, RunHost, id)
    /// </summary>
    [DataDiscoverer("Xunit.Sdk.DataDiscoverer", "xunit.core")]
    [AttributeUsage(AttributeTargets.Method, AllowMultiple = true, Inherited = true)]
    public class BuildAndRunAttribute : DataAttribute
    {
        private readonly IEnumerable<object?[]> _data;


#if TARGET_WASI
        // remove when wasi is refectored and use Configuration
        public BuildAndRunAttribute(bool aot=false, string? config=null, params object?[] parameters)
        {
            _data = BuildTestBase.ConfigWithAOTData(aot, config)
                    .Multiply(parameters)
                    .UnwrapItemsAsArrays().ToList();
        }
#else
        public BuildAndRunAttribute(bool aot=false, Configuration config=Configuration.Undefined, params object?[] parameters)
        {
            _data = BuildTestBase.ConfigWithAOTData(aot, config)
                    .Multiply(parameters)
                    .UnwrapItemsAsArrays().ToList();
        }
#endif
        public override IEnumerable<object?[]> GetData(MethodInfo testMethod) => _data;
    }
}
